==> zh-cn-2.9.1.zip: zh-cn/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = '内容';
$GLOBALS['__l10n']['To menu'] = '菜单';
$GLOBALS['__l10n']['To search'] = '搜索';
$GLOBALS['__l10n']['By'] = '作者';
$GLOBALS['__l10n']['by'] = '作者';
$GLOBALS['__l10n']['on'] = '于';
$GLOBALS['__l10n']['On'] = '于';
$GLOBALS['__l10n']['Continue reading'] = '继续阅读';
$GLOBALS['__l10n']['no comments'] = '没有评论';
$GLOBALS['__l10n']['one comment'] = '一个评论';
$GLOBALS['__l10n']['%d comments'] = '%d 个评论';
$GLOBALS['__l10n']['no trackbacks'] = '没有 trackback';
$GLOBALS['__l10n']['one trackback'] = '一个 trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d 个 trackback';
$GLOBALS['__l10n']['no attachments'] = '没有附件';
$GLOBALS['__l10n']['one attachment'] = '一个附件';
$GLOBALS['__l10n']['%d attachments'] = '%d 个附件';
$GLOBALS['__l10n']['previous entries'] = '前一篇文章';
$GLOBALS['__l10n']['page'] = '页面';
$GLOBALS['__l10n']['of'] = 'of';
$GLOBALS['__l10n']['next entries'] = '下一篇文章';
$GLOBALS['__l10n']['Search'] = '搜索';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = '您搜索 <em>%1$s</em> 没有匹配结果。';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = '您搜索 <em>%1$s</em> 返回 <strong>%2$s</strong> 个结果。';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = '您搜索 <em>%1$s</em> 返回 <strong>%2$s</strong> 个结果。';
$GLOBALS['__l10n']['Home'] = '主页';
$GLOBALS['__l10n']['All keywords'] = '所有关键字';
$GLOBALS['__l10n']['Best of me'] = '我最好的文章';
$GLOBALS['__l10n']['Languages'] = '语言';
$GLOBALS['__l10n']['Categories'] = '分类目录';
$GLOBALS['__l10n']['Subcategories'] = '子分类目录';
$GLOBALS['__l10n']['Archives'] = '归档';
$GLOBALS['__l10n']['Links'] = '链接';
$GLOBALS['__l10n']['Subscribe'] = '订阅';
$GLOBALS['__l10n']['Entries feed'] = '文章 feed';
$GLOBALS['__l10n']['Comments feed'] = '评论 feed';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = '此博客评论的 Atom feed';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = '此分类目录文章的 Atom feed';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = '此分类目录评论的 Atom feed';
$GLOBALS['__l10n']['This post\'s comments feed'] = '这篇文章的评论 feed';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = '这篇文章的评论 Atom feed';
$GLOBALS['__l10n']['Attachments'] = '附件';
$GLOBALS['__l10n']['Permalink'] = '永久链接';
$GLOBALS['__l10n']['Comments'] = '评论';
$GLOBALS['__l10n']['Your comment'] = '您的评论';
$GLOBALS['__l10n']['Your comment has been published.'] = '您的评论已发布。';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = '您的评论已提交并将被复审以发布。';
$GLOBALS['__l10n']['Add a comment'] = '添加一个评论';
$GLOBALS['__l10n']['Name or nickname'] = '姓名或昵称';
$GLOBALS['__l10n']['Email address'] = '邮件地址';
$GLOBALS['__l10n']['Website'] = '网站';
$GLOBALS['__l10n']['optional'] = '可选的';
$GLOBALS['__l10n']['Comment'] = '评论';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML 代码以文本显示，网站地址会被自动转化。';
$GLOBALS['__l10n']['Remember me on this blog'] = '在这个博客上记住我';
$GLOBALS['__l10n']['preview'] = '预览';
$GLOBALS['__l10n']['send'] = '发送';
$GLOBALS['__l10n']['They posted on the same topic'] = '他／她们讨论同一个话题';
$GLOBALS['__l10n']['Trackback URL'] = 'Trackback URL';
$GLOBALS['__l10n']['You must provide an author name'] = '您必须提供作者姓名';
$GLOBALS['__l10n']['You must provide a comment'] = '您必须提供一个评论';
$GLOBALS['__l10n']['Email address is not valid'] = '邮件地址无效';
$GLOBALS['__l10n']['Document not found'] = '文件不存在';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = '您寻找的文件不存在。';
$GLOBALS['__l10n']['Powered by %s'] = 'Powered by %s';
$GLOBALS['__l10n']['Subscribe to'] = '订阅到';
$GLOBALS['__l10n']['What is an RSS feed?'] = '什么是 RSS feed？';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'RSS feed 是一个免费的博客摘要。它提供内容（文章或者评论）或者内容的摘要，以及到完整版本的链接和其他元标记。最新发表的条目可以使用您喜欢的 RSS <a href="http://en.wikipedia.org/wiki/Aggregator">聚合器</a> 来阅读。';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = '仅需复制下列 URL 到您的聚合器：';
$GLOBALS['__l10n']['Password needed'] = '需要密码';
$GLOBALS['__l10n']['You must give a password to access this area.'] = '您必须提供密码以进入这一区域。';
$GLOBALS['__l10n']['Password:'] = '密码：';
$GLOBALS['__l10n']['You must provide a valid email address.'] = '您必须提供有效的邮件地址。';
$GLOBALS['__l10n']['Read'] = '读取';

==> zh-cn-2.13.zip: zh-cn/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = '内容';
$GLOBALS['__l10n']['To menu'] = '菜单';
$GLOBALS['__l10n']['To search'] = '搜索';
$GLOBALS['__l10n']['By'] = '作者';
$GLOBALS['__l10n']['by'] = '作者';
$GLOBALS['__l10n']['on'] = '于';
$GLOBALS['__l10n']['On'] = '于';
$GLOBALS['__l10n']['Continue reading'] = '继续阅读';
$GLOBALS['__l10n']['no comments'] = '没有评论';
$GLOBALS['__l10n']['one comment'] = '一个评论';
$GLOBALS['__l10n']['%d comments'] = '%d 个评论';
$GLOBALS['__l10n']['no trackbacks'] = '没有 trackback';
$GLOBALS['__l10n']['one trackback'] = '一个 trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d 个 trackback';
$GLOBALS['__l10n']['no attachments'] = '没有附件';
$GLOBALS['__l10n']['one attachment'] = '一个附件';
$GLOBALS['__l10n']['%d attachments'] = '%d 个附件';
$GLOBALS['__l10n']['previous entries'] = '前一篇文章';
$GLOBALS['__l10n']['page'] = '页面';
$GLOBALS['__l10n']['of'] = 'of';
$GLOBALS['__l10n']['next entries'] = '下一篇文章';
$GLOBALS['__l10n']['Search'] = '搜索';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = '您搜索 <em>%1$s</em> 没有匹配结果。';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = '您搜索 <em>%1$s</em> 返回 <strong>%2$s</strong> 个结果。';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = '您搜索 <em>%1$s</em> 返回 <strong>%2$s</strong> 个结果。';
$GLOBALS['__l10n']['Home'] = '主页';
$GLOBALS['__l10n']['All keywords'] = '所有关键字';
$GLOBALS['__l10n']['Best of me'] = '我最好的文章';
$GLOBALS['__l10n']['Languages'] = '语言';
$GLOBALS['__l10n']['Categories'] = '分类目录';
$GLOBALS['__l10n']['Subcategories'] = '子分类目录';
$GLOBALS['__l10n']['Archives'] = '归档';
$GLOBALS['__l10n']['Links'] = '链接';
$GLOBALS['__l10n']['Subscribe'] = '订阅';
$GLOBALS['__l10n']['Entries feed'] = '文章 feed';
$GLOBALS['__l10n']['Comments feed'] = '评论 feed';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = '此博客评论的 Atom feed';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = '此分类目录文章的 Atom feed';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = '此分类目录评论的 Atom feed';
$GLOBALS['__l10n']['This post\'s comments feed'] = '这篇文章的评论 feed';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = '这篇文章的评论 Atom feed';
$GLOBALS['__l10n']['Attachments'] = '附件';
$GLOBALS['__l10n']['Permalink'] = '永久链接';
$GLOBALS['__l10n']['Comments'] = '评论';
$GLOBALS['__l10n']['Your comment'] = '您的评论';
$GLOBALS['__l10n']['Your comment has been published.'] = '您的评论已发布。';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = '您的评论已提交并将被复审以发布。';
$GLOBALS['__l10n']['Add a comment'] = '添加一个评论';
$GLOBALS['__l10n']['Name or nickname'] = '姓名或昵称';
$GLOBALS['__l10n']['Email address'] = '邮件地址';
$GLOBALS['__l10n']['Website'] = '网站';
$GLOBALS['__l10n']['optional'] = '可选的';
$GLOBALS['__l10n']['Comment'] = '评论';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML 代码以文本显示，网站地址会被自动转化。';
$GLOBALS['__l10n']['Remember me on this blog'] = '在这个博客上记住我';
$GLOBALS['__l10n']['preview'] = '预览';
$GLOBALS['__l10n']['send'] = '发送';
$GLOBALS['__l10n']['They posted on the same topic'] = '他／她们讨论同一个话题';
$GLOBALS['__l10n']['Trackback URL'] = 'Trackback URL';
$GLOBALS['__l10n']['You must provide an author name'] = '您必须提供作者姓名';
$GLOBALS['__l10n']['You must provide a comment'] = '您必须提供一个评论';
$GLOBALS['__l10n']['Email address is not valid'] = '邮件地址无效';
$GLOBALS['__l10n']['Document not found'] = '文件不存在';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = '您寻找的文件不存在。';
$GLOBALS['__l10n']['Powered by %s'] = 'Powered by %s';
$GLOBALS['__l10n']['Subscribe to'] = '订阅到';
$GLOBALS['__l10n']['What is an RSS feed?'] = '什么是 RSS feed？';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'RSS feed 是一个免费的博客摘要。它提供内容（文章或者评论）或者内容的摘要，以及到完整版本的链接和其他元标记。最新发表的条目可以使用您喜欢的 RSS <a href="http://en.wikipedia.org/wiki/Aggregator">聚合器</a> 来阅读。';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = '仅需复制下列 URL 到您的聚合器：';
$GLOBALS['__l10n']['Password needed'] = '需要密码';
$GLOBALS['__l10n']['You must give a password to access this area.'] = '您必须提供密码以进入这一区域。';
$GLOBALS['__l10n']['Password:'] = '密码：';
$GLOBALS['__l10n']['You must provide a valid email address.'] = '您必须提供有效的邮件地址。';
$GLOBALS['__l10n']['Read'] = '读取';
$GLOBALS['__l10n']['in'] = '';
$GLOBALS['__l10n']['In'] = '';
$GLOBALS['__l10n']['Page top'] = '';
$GLOBALS['__l10n']['toDay'] = '';
$GLOBALS['__l10n']['FromDay'] = '';
$GLOBALS['__l10n']['By category'] = '';
$GLOBALS['__l10n']['By date'] = '';
$GLOBALS['__l10n']['By tag'] = '';
$GLOBALS['__l10n']['Blog menu'] = '菜单';
$GLOBALS['__l10n']['Etra menu'] = '菜单';
$GLOBALS['__l10n']['Blog info'] = '';
